Syntax Diagrams
===============

Python library for rendering syntax diagrams (a.k.a. railroad diagrams).


Features
--------

-   Automatic line wrapping, keeping width of the diagram below limits.
-   Clever rendering of optionals, avoiding clutter where possible.
-   Automatic right-to-left rendering in one-or-more loops.
-   Producing SVGs or ASCII art.
-   `Try it in your browser.`__
-   See also: `sphinx-syntax`__, a Sphinx plugin for documenting syntax grammars.

__ https://taminomara.github.io/syntax-diagrams/try/
__ https://taminomara.github.io/sphinx-syntax/


Table of contents
-----------------

.. toctree::
    :hidden:

    Try in browser <https://taminomara.github.io/syntax-diagrams/try/>

.. toctree::
    :maxdepth: 2

    quickstart
    describe
    render
    advanced
